<?php

namespace WglAddons\Widgets;

if ( ! defined( 'ABSPATH' ) ) exit; // Abort, if accessed directly.

use WglAddons\Includes\Wgl_Icons;
use WglAddons\Includes\Wgl_Carousel_Settings;
use WglAddons\Includes\Wgl_Elementor_Helper;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Css_Filter;


class Wgl_Flipbox extends Widget_Base {
	
	public function get_name() {
		return 'wgl-flipbox';
	}

	public function get_title() {
		return esc_html__( 'WGL Flipbox', 'littledino-core' );
	}

	public function get_icon() {
		return 'wgl-flipbox';
	}

	public function get_categories() {
		return [ 'wgl-extensions' ];
	}

	protected function _register_controls() {
		$theme_color = esc_attr(\LittleDino_Theme_Helper::get_option('theme-custom-color'));
		$second_color = esc_attr(\LittleDino_Theme_Helper::get_option('theme-secondary-color'));
		$third_color = esc_attr(\LittleDino_Theme_Helper::get_option('theme-third-color'));
		$header_font_color = esc_attr(\LittleDino_Theme_Helper::get_option('header-font')['color']);
		$main_font_color = esc_attr(\LittleDino_Theme_Helper::get_option('main-font')['color']);


		/*-----------------------------------------------------------------------------------*/
		/*  CONTENT -> GENERAL
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_flipbox_settings',
			[ 'label' => esc_html__( 'General', 'littledino-core' ) ]
		);

		$this->add_control(
			'flip_direction',
			[
				'label' => esc_html__( 'Border Type', 'Border Control', 'littledino-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'flip_right' => esc_html__( 'Flip to Right', 'littledino-core' ),
					'flip_left' => esc_html__( 'Flip to Left', 'littledino-core' ),
					'flip_top' => esc_html__( 'Flip to Top', 'littledino-core' ),
					'flip_bottom' => esc_html__( 'Flip to Bottom', 'littledino-core' ),
				],
				'default' => 'flip_right',
			]
		);

		$this->add_control(
			'alignment',
			[
				'label' => esc_html__( 'Alignment', 'littledino-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'littledino-core' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'littledino-core' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'littledino-core' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'center',
				'toggle' => true,
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_wrap' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'flipbox_height',
			[
				'label' => esc_html__( 'Custom Flipbox Height (px)', 'littledino-core' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 150,
				'step' => 10,
				'default' => 320,
				'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox' => 'height: {{VALUE}}px;',
				],
			]
		);

		$this->end_controls_section();


		/*-----------------------------------------------------------------------------------*/
		/*  CONTENT -> ICON
		/*-----------------------------------------------------------------------------------*/


		$this->start_controls_section(
			'section_content_icon',
			[ 'label' => esc_html__( 'Icon', 'littledino-core' ) ]
		);

		$this->start_controls_tabs( 'flipbox_icon' );

		$this->start_controls_tab(
			'flipbox_front_icon',
			[ 'label' => esc_html__( 'Front', 'littledino-core' ) ]
		);

		Wgl_Icons::init(
			$this,
			[
				'label' => esc_html__( 'Flipbox', 'littledino-core' ),
				'output' => '',
				'section' => false,
				'prefix' => 'front_'
			]
		);      

		$this->end_controls_tab();

		$this->start_controls_tab(
			'flipbox_back_icon',
			[ 'label' => esc_html__( 'Back', 'littledino-core' ) ]
		);

		Wgl_Icons::init(
			$this,
			[
				'label' => esc_html__( 'Flipbox', 'littledino-core' ),
				'output' => '',
				'section' => false,
				'prefix' => 'back_'
			]
		);      

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();


		/*-----------------------------------------------------------------------------------*/
		/*  CONTENT -> CONTENT
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'wgl_ib_content',
			[ 'label' => esc_html__( 'Content', 'littledino-core' ) ]
		);

		$this->start_controls_tabs( 'flipbox_content' );

		$this->start_controls_tab(
			'flipbox_front_content',
			[ 'label' => esc_html__( 'Front', 'littledino-core' ) ]
		);

		$this->add_control(
			'front_title',
			[
				'label'         => esc_html__( 'Title', 'littledino-core' ),
				'type'          => Controls_Manager::TEXT,
				'label_block'   => true,
				'default'       => esc_html__( 'This is the heading​', 'littledino-core' ),
			]
		);        

		$this->add_control(
			'front_content',
			[
				'label' => esc_html__( 'Flipbox Text', 'littledino-core' ),
				'type' => Controls_Manager::WYSIWYG,
				'dynamic' => [ 'active' => true ],
				'placeholder' => esc_attr__( 'Description Text', 'littledino-core' ),
				'label_block' => true,
				'default' => esc_html__( 'Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'littledino-core' ),
			]
		);
		
		$this->end_controls_tab();

		$this->start_controls_tab(
			'flipbox_back_content',
			[ 'label' => esc_html__( 'Back', 'littledino-core' ) ]
		);

		$this->add_control(
			'back_title',
			[
				'label' => esc_html__( 'Title', 'littledino-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_attr__( 'This is the heading​', 'littledino-core' ),
			]
		);        

		$this->add_control(
			'back_content',
			[
				'label' => esc_html__( 'Flipbox Text', 'littledino-core' ),
				'type' => Controls_Manager::WYSIWYG,
				'dynamic' => [ 'active' => true ],
				'placeholder' => esc_attr__( 'Description Text', 'littledino-core' ),
				'label_block' => true,
				'default' => esc_html__( 'Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'littledino-core' ),                
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();


		/*-----------------------------------------------------------------------------------*/
		/*  CONTENT -> LINK
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_content_link',
			[ 'label' => esc_html__( 'Link', 'littledino-core' ) ]
		);      

		$this->add_control(
			'add_item_link',
			[
				'label' => esc_html__( 'Full module button','littledino-core' ),
				'type' => Controls_Manager::SWITCHER,
				'condition' => [ 'add_read_more!' => 'yes' ],
				'description' => esc_html__( 'Clickable at any place', 'littledino-core' ),
				'label_on' => esc_html__( 'On', 'littledino-core' ),
				'label_off' => esc_html__( 'Off', 'littledino-core' ),
				'return_value' => 'yes',
			]
		);

		$this->add_control(
			'item_link',
			[
				'label' => esc_html__( 'Link', 'littledino-core' ),
				'type' => Controls_Manager::URL,
				'condition'=> [ 'add_item_link' => 'yes' ],
				'dynamic' => [ 'active' => true ],
				'label_block' => true,
			]
		);

		$this->add_control(
			'add_read_more',
			[
				'label' => esc_html__( 'Add \'Read More\' Button', 'littledino-core' ),
				'type' => Controls_Manager::SWITCHER,
				'condition' => [ 'add_item_link!' => 'yes' ], 
				'label_on' => esc_html__( 'On', 'littledino-core' ),
				'label_off' => esc_html__( 'Off', 'littledino-core' ),
				'return_value' => 'yes',
			]
		);   

		$this->add_control(
			'read_more_text',
			[
				'label' => esc_html__( 'Button Text', 'littledino-core' ),
				'type' => Controls_Manager::TEXT,
				'condition' => [ 'add_read_more' => 'yes' ],
				'dynamic' => [ 'active' => true ],
				'label_block' => true,
				'default' => esc_html__( 'Read More', 'littledino-core' ),
			]
		);  

		$this->add_control(
			'link',
			[
				'label' => esc_html__( 'Button Link', 'littledino-core' ),
				'type' => Controls_Manager::URL,
				'condition' => [ 'add_read_more' => 'yes' ],
				'dynamic' => [ 'active' => true ],
				'label_block' => true,
			]
		);  

		$this->end_controls_section();       


		/*-----------------------------------------------------------------------------------*/
		/*  STYLE -> GENERAL
		/*-----------------------------------------------------------------------------------*/  

		$this->start_controls_section(
			'section_style_general',
			[
				'label' => esc_html__( 'General', 'littledino-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs( 'tabs_style_general' );

		$this->start_controls_tab(
			'flipbox_front_style',
			[ 'label' => esc_html__( 'Front', 'littledino-core' ) ]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'front_background',
				'label' => esc_html__( 'Front Background', 'littledino-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .wgl-flipbox_front',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'flipbox_back_style',
			[ 'label' => esc_html__( 'Back', 'littledino-core' ) ]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'back_background',
				'label' => esc_html__( 'Back Background', 'littledino-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .wgl-flipbox_back',
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_responsive_control(
			'flipbox_padding',
			[
				'label' => esc_html__( 'Padding', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'separator' => 'before',
				'default'   => [
					'top' => 20,
					'right' => 20,
					'bottom' => 20,
					'left' => 20,
					'unit'  => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_front, {{WRAPPER}} .wgl-flipbox_back' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'flipbox_margin',
			[
				'label' => esc_html__( 'Margin', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_front, {{WRAPPER}} .wgl-flipbox_back' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'flipbox_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'default'   => [
					'top' => 15,
					'right' => 15,
					'bottom' => 15,
					'left' => 15,
					'unit'  => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_front, {{WRAPPER}} .wgl-flipbox_back' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],

			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'flipbox_border',
				'selector' => '{{WRAPPER}} .wgl-flipbox_front, {{WRAPPER}} .wgl-flipbox_back',
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'flipbox_shadow',
				'selector' => '{{WRAPPER}} .wgl-flipbox_front, {{WRAPPER}} .wgl-flipbox_back',
			]
		);

		$this->end_controls_section();


		/*-----------------------------------------------------------------------------------*/
		/*  STYLE -> MEDIA
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_style_icon',
			[
				'label' => esc_html__( 'Media', 'littledino-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs( 'media_styles' );

		$this->start_controls_tab(
			'front_media_style',
			[ 'label' => esc_html__( 'Front', 'littledino-core' ) ]
		);

		$this->add_responsive_control(
			'front_media_margin',
			[
				'label' => esc_html__( 'Margin', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_front .wgl-flipbox_media-wrap' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'front_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $theme_color,
				'condition' => [ 'front_icon_type' => 'font' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_front .wgl-icon' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'front_icon_size',
			[
				'label' => esc_html__( 'Icon Size', 'littledino-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 16,
						'max' => 100,
					],
				],
				'default'   => [
					'unit' => 'px',
					'size' => 55,
				],
				'condition' => [ 'front_icon_type'   => 'font' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_front .wgl-icon' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'back_media_style',
			[ 'label' => esc_html__( 'Back', 'littledino-core' ) ]
		);

		$this->add_responsive_control(
			'back_media_margin',
			[
				'label' => esc_html__( 'Margin', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_back .wgl-flipbox_media-wrap' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'back_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $theme_color,
				'condition' => [ 'back_icon_type'   => 'font' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_back .wgl-icon' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'back_icon_size',
			[
				'label' => esc_html__( 'Icon Size', 'littledino-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 16,
						'max' => 100,
					],
				],
				'default'   => [
					'unit' => 'px',
					'size' => 55,
				],
				'condition' => [ 'back_icon_type' => 'font' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_back .wgl-icon' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();


		/*-----------------------------------------------------------------------------------*/
		/*  STYLE -> TITLE
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_style_title',
			[
				'label' => esc_html__( 'Title', 'littledino-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label' => esc_html__( 'HTML Tag', 'littledino-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
					'div' => 'DIV',
					'span' => 'SPAN',
				],
				'default' => 'h3',
			]
		);

		$this->start_controls_tabs( 'title_styles' );

		$this->start_controls_tab(
			'front_title_style',
			[ 'label' => esc_html__( 'Front', 'littledino-core' ) ]
		);

		$this->add_responsive_control(
			'front_title_offset',
			[
				'label' => esc_html__( 'Title Offset', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'default' => [
					'top' => 10,
					'right' => 0,
					'bottom' => 8,
					'left' => 0,
					'unit'  => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_front .wgl-flipbox_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'custom_front_fonts_title',
				'selector' => '{{WRAPPER}} .wgl-flipbox_front .wgl-flipbox_title',
			]
		);

		$this->add_control(
			'front_title_color',
			[
				'label' => esc_html__( 'Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $header_font_color,
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_front .wgl-flipbox_title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'back_title_style',
			[ 'label' => esc_html__( 'Back', 'littledino-core' ) ]
		);

		$this->add_responsive_control(
			'back_title_offset',
			[
				'label' => esc_html__( 'Title Offset', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'default'   => [
					'top' => 10,
					'right' => 0,
					'bottom' => 8,
					'left' => 0,
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_back .wgl-flipbox_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'custom_back_fonts_title',
				'selector' => '{{WRAPPER}} .wgl-flipbox_back .wgl-flipbox_title',
			]
		);

		$this->add_control(
			'back_title_color',
			[
				'label' => esc_html__( 'Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $header_font_color,
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_back .wgl-flipbox_title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();

		
		/*-----------------------------------------------------------------------------------*/
		/*  STYLE -> CONTENT
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_style_content',
			[
				'label' => esc_html__( 'Content', 'littledino-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs( 'content_styles' );

		$this->start_controls_tab(
			'front_content_style',
			[ 'label' => esc_html__( 'Front', 'littledino-core' ) ]
		);

		$this->add_responsive_control(
			'front_content_offset',
			[
				'label' => esc_html__( 'Content Offset', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'default'   => [
					'top' => 0,
					'right' => 0,
					'bottom' => 0,
					'left' => 0,
					'unit'  => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_front .wgl-flipbox_content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'custom_front_fonts_content',
				'selector' => '{{WRAPPER}} .wgl-flipbox_front .wgl-flipbox_content',
			]
		);

		$this->add_control(
			'front_content_color',
			[
				'label' => esc_html__( 'Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $main_font_color,
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_front .wgl-flipbox_content' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'back_content_style',
			[ 'label' => esc_html__( 'Back', 'littledino-core' ) ]
		);

		$this->add_responsive_control(
			'back_content_offset',
			[
				'label' => esc_html__( 'Content Offset', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'default'   => [
					'top' => 0,
					'right' => 0,
					'bottom' => 0,
					'left' => 0,
					'unit'  => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_back .wgl-flipbox_content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'custom_back_fonts_content',
				'selector' => '{{WRAPPER}} .wgl-flipbox_back .wgl-flipbox_content',
			]
		);

		$this->add_control(
			'back_content_color',
			[
				'label' => esc_html__( 'Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $main_font_color,
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_back .wgl-flipbox_content' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();   
		$this->end_controls_section();          
		

		/*-----------------------------------------------------------------------------------*/
		/*  STYLE -> BUTTON
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_style_button',
			[
				'label' => esc_html__( 'Button', 'littledino-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [ 'add_read_more!' => '' ],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .wgl-flipbox_readmore',
			]
		);

		$this->add_responsive_control(
			'b_padding',
			[
				'label' => esc_html__( 'Padding', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'default' => [
					'top' => 14,
					'right' => 24,
					'bottom' => 14,
					'left' => 24,
					'unit'  => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_readmore' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'b_margin',
			[
				'label' => esc_html__( 'Margin', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_readmore' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'b_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_readmore' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],

			]
		);

		$this->start_controls_tabs( 'button_color_tab' );

		$this->start_controls_tab(
			'custom_button_color_normal',
			[ 'label' => esc_html__( 'Normal' , 'littledino-core' ) ]
		);

		$this->add_control(
			'button_background',
			[
				'label' => esc_html__( 'Background Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => esc_attr($theme_color),
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_readmore' => 'background: {{VALUE}};',
				],
			]
		);        

		$this->add_control(
			'button_color',
			[
				'label' => esc_html__( 'Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_readmore' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'button_border',
				'label' => esc_html__( 'Border Type', 'littledino-core' ),
				'selector' => '{{WRAPPER}} .wgl-flipbox_readmore',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'button_shadow',
				'selectors' =>  '{{WRAPPER}} .wgl-flipbox_readmore',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'custom_button_color_hover',
			[ 'label' => esc_html__( 'Hover' , 'littledino-core' ) ]
		);

		$this->add_control(
			'button_background_hover',
			[
				'label' => esc_html__( 'Background Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $second_color,
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_readmore:hover' => 'background: {{VALUE}};'
				],
			]
		);         

		$this->add_control(
			'button_color_hover',
			[
				'label' => esc_html__( 'Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .wgl-flipbox_readmore:hover' => 'color: {{VALUE}};'
				],
			]
		);        

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'button_border_hover',
				'label' => esc_html__( 'Border Type', 'littledino-core' ),
				'selector' => '{{WRAPPER}} .wgl-flipbox_readmore:hover',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'button_shadow_hover',
				'selector' => '{{WRAPPER}} .wgl-flipbox_readmore:hover',
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}

	public function render(){
		
		$_s = $this->get_settings_for_display();

		// HTML tags allowed for rendering
		$allowed_html = [
			'a' => [
				'href' => true, 'title' => true,
				'class' => true, 'style' => true,
			],
			'br' => [ 'class' => true ],
			'em' => [ 'class' => true ],
			'strong' => [ 'class' => true ],
			'span' => [ 'class' => true, 'style' => true ],
			'p' => [ 'class' => true, 'style' => true ],
			'ul' => [ 'class' => true, 'style' => true ],
			'ol' => [ 'class' => true, 'style' => true ],
		];

		$this->add_render_attribute(
			[
				'flipbox' => [
					'class' => [
						'wgl-flipbox', 
						'type_'.$_s['flip_direction'],
					],
				],
				'flipbox_link' => [
					'class' => [
						'wgl-flipbox_readmore',
						'wgl-button',
						'elementor-button',
						'elementor-size-xl',
					],
					'href' => esc_url($_s['link']['url'] ),
					'target' => $_s['link']['is_external'] ? '_blank' : '_self',
					'rel' => $_s['link']['nofollow'] ? 'nofollow' : '',
				],
				'item_link' => [
					'class' => 'wgl-flipbox_item-link',
					'href' => esc_url($_s['item_link']['url'] ),
					'target' => $_s['item_link']['is_external'] ? '_blank' : '_self',
					'rel' => $_s['item_link']['nofollow'] ? 'nofollow' : '',
				],
			]
		);

		// Icon/Image output
		ob_start();
		if (!empty($_s['front_icon_type'])) {
			$icons = new Wgl_Icons;
			echo $icons->build($this, $_s, 'front_' );
		}
		$front_media = ob_get_clean();
		// Icon/Image output
		ob_start();
		if (!empty($_s['back_icon_type'])) {
			$icons = new Wgl_Icons;
			echo $icons->build($this, $_s, 'back_' );
		}
		$back_media = ob_get_clean();

		?>
		<div <?php echo $this->get_render_attribute_string( 'flipbox' ); ?>>
			<div class="wgl-flipbox_wrap">
				<div class="wgl-flipbox_front"><?php
					if ($_s['front_icon_type'] != '') {?>
					<div class="wgl-flipbox_media-wrap"><?php 
						if (!empty($front_media)){
							echo $front_media;
						}?>
					</div><?php
					}
					if (!empty($_s['front_title'])) {?>
						<<?php echo $_s['title_tag']; ?> class="wgl-flipbox_title"><?php echo wp_kses( $_s['front_title'], $allowed_html );?></<?php echo $_s['title_tag']; ?>><?php
					}
					if (!empty($_s['front_content'])) {?>
						<div class="wgl-flipbox_content"><?php echo wp_kses( $_s['front_content'], $allowed_html );?></div><?php
					}?>
				</div>
				<div class="wgl-flipbox_back"><?php
					if ($_s['back_icon_type'] != '') {?>
					<div class="wgl-flipbox_media-wrap"><?php 
						if (!empty($back_media)){
							echo $back_media;
						}?>
					</div><?php
					}
					if (!empty($_s['back_title'])) {?>
						<<?php echo $_s['title_tag']; ?> class="wgl-flipbox_title"><?php echo wp_kses( $_s['back_title'], $allowed_html );?></<?php echo $_s['title_tag']; ?>><?php
					}
					if (!empty($_s['back_content'])) {?>
						<div class="wgl-flipbox_content"><?php echo wp_kses( $_s['back_content'], $allowed_html );?></div><?php
					}
					if ((bool)$_s['add_read_more']) {?>
						<div class="wgl-flipbox_button-wrap"><a <?php echo $this->get_render_attribute_string( 'flipbox_link' ); ?>><?php echo esc_html($_s['read_more_text']);?></a></div><?php
					}?>
				</div>
			</div><?php
			if ((bool)$_s['add_item_link']) {?>
				<a <?php echo $this->get_render_attribute_string( 'item_link' ); ?>></a><?php
			}?>
		</div>

		<?php     
	}
}