<?php

namespace WglAddons\Widgets;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

use WglAddons\Includes\Wgl_Icons;
use WglAddons\Includes\Wgl_Elementor_Helper;
use WglAddons\Templates\WglToggleAccordion;
use Elementor\Frontend;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;


class Wgl_Toggle_Accordion extends Widget_Base {
	
	public function get_name() {
		return 'wgl-toggle-accordion';
	}

	public function get_title() {
		return esc_html__( 'WGL Toggle/Accordion', 'littledino-core' );
	}

	public function get_icon() {
		return 'wgl-toggle-accordion';
	}

	public function get_categories() {
		return [ 'wgl-extensions' ];
	}

	// Adding the controls fields for the premium title
	// This will controls the animation, colors and background, dimensions etc
	protected function _register_controls() {
		$theme_color = esc_attr(\LittleDino_Theme_Helper::get_option('theme-custom-color'));
		$second_color = esc_attr(\LittleDino_Theme_Helper::get_option('theme-secondary-color'));
		$third_color = esc_attr(\LittleDino_Theme_Helper::get_option('theme-third-color'));
		$header_font_color = esc_attr(\LittleDino_Theme_Helper::get_option('header-font')['color']);
		$main_font_color = esc_attr(\LittleDino_Theme_Helper::get_option('main-font')['color']);

		/*-----------------------------------------------------------------------------------*/
		/*  CONTENT SECTION
		/*-----------------------------------------------------------------------------------*/

		/*-----------------------------------------------------------------------------------*/
		/*  CONTENT -> GENERAL
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_content_general',
			[ 'label' => esc_html__( 'General', 'littledino-core') ]
		);

		$this->add_control(
			'acc_type',
			[
				'label' => esc_html__( 'Type', 'littledino-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'accordion',
				'options' => [
					'accordion' => esc_html__( 'Accordion', 'littledino-core' ),
					'toggle' => esc_html__( 'Toggle', 'littledino-core' ),
				],
			]
		);
		
		$this->add_control(
			'enable_acc_icon',
			[
				'label' => esc_html__( 'Icon', 'littledino-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'def',
				'options' => [
					'none' => esc_html__( 'None', 'littledino-core' ),
					'def' => esc_html__( 'Default', 'littledino-core' ),
					'custom' => esc_html__( 'Custom', 'littledino-core' ),
				],
			]
		);
		
		$this->add_control(
			'acc_icon',
			[
				'label' => esc_html__( 'Toggle Icon', 'littledino-core' ),
				'type' => Controls_Manager::ICON,
				'default' => 'fa fa-angle-right',
				'include' => [
					'fa fa-arrow-right',
					'fa fa-long-arrow-right',
					'fa fa-chevron-right',
					'fa fa-chevron-circle-right',
					'fa fa-arrow-circle-right',
					'fa fa-angle-right',
					'fa fa-angle-double-right',
					'fa fa-plus',
				],
				'condition' => [ 'enable_acc_icon' => 'custom' ],
			]
		);

		$this->add_responsive_control(
			'acc_margin',
			[
				'label' => esc_html__( 'Margin', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();  


		/*-----------------------------------------------------------------------------------*/
		/*  CONTENT -> CONTENT
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_content_content',
			[ 'label' => esc_html__( 'Content', 'littledino-core' ) ]
		);

		$this->add_responsive_control(
			'acc_tab_panel_margin',
			[
				'label' => esc_html__( 'Tab Panel Margin', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'default' => [
					'top' => 0,
					'right' => 0,
					'bottom' => 20,
					'left' => 0,
					'unit' => 'px',
					'isLinked' => false
				],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_panel' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'acc_tab',
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => [
					['acc_tab_title' => esc_html__( 'Tab Title 1', 'littledino-core'),
					'acc_tab_def_active' => 'yes'],
					['acc_tab_title' => esc_html__( 'Tab Title 2', 'littledino-core')],
					['acc_tab_title' => esc_html__( 'Tab Title 3', 'littledino-core')],
				],
				'fields' => [
					[
						'name' => 'acc_tab_title',
						'label' => esc_html__( 'Tab Title', 'littledino-core'),
						'type' => Controls_Manager::TEXTAREA,
						'default' => esc_html__( 'Tab Title', 'littledino-core'),
						'dynamic' => ['active' => true],
					],
					[
						'name' => 'acc_tab_def_active',
						'label' => esc_html__( 'Active as Default', 'littledino-core'),
						'type' => Controls_Manager::SWITCHER,
						'default' => 'no',
						'return_value' => 'yes',
					],
					[
						'name' => 'acc_content_type',
						'label' => esc_html__( 'Content Type', 'littledino-core'),
						'type' => Controls_Manager::SELECT,
						'options' => [
							'content' => esc_html__('Content', 'littledino-core'),
							'template' => esc_html__('Saved Templates', 'littledino-core'),
						],
						'default' => 'content',
					],
					[
						'name' => 'acc_content_templates',
						'label' => esc_html__( 'Choose Template', 'littledino-core'),
						'type' => Controls_Manager::SELECT,
						'options' => Wgl_Elementor_Helper::get_instance()->get_elementor_templates(),
						'condition' => [
							'acc_content_type' => 'template',
						],
					],
					[
						'name' => 'acc_content',
						'label' => esc_html__( 'Tab Content', 'littledino-core'),
						'type' => Controls_Manager::WYSIWYG,
						'default' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Optio, neque qui velit. Magni dolorum quidem ipsam eligendi, totam, facilis laudantium cum accusamus ullam voluptatibus commodi numquam, error, est. Ea, consequatur.', 'littledino-core' ),
						'dynamic' => ['active' => true],
						'condition' => [
							'acc_content_type' => 'content',
						],
					],
				],
				'title_field' => '{{acc_tab_title}}',
			]
		);

		$this->end_controls_section();      


		/*-----------------------------------------------------------------------------------*/
		/*  STYLE SECTION
		/*-----------------------------------------------------------------------------------*/

		/*-----------------------------------------------------------------------------------*/
		/*  STYLE -> TITLE
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_style_title',
			[
				'label' => esc_html__( 'Title', 'littledino-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'acc_title_typo',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .wgl-accordion_title',
			]
		);

		$this->add_control(
			'acc_title_tag',
			[
				'label' => esc_html__( 'Title HTML Tag', 'littledino-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
					'div' => 'div',
				],
				'default' => 'h4',
			]
		);

		$this->add_responsive_control(
			'acc_title_padding',
			[
				'label' => esc_html__( 'Padding', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'default' => [
					'top' => 0,
					'right' => 0,
					'bottom' => 2,
					'left' => 0,
					'unit' => 'px',
					'isLinked' => false
				],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'acc_title_margin',
			[
				'label' => esc_html__( 'Margin', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		// Tabs
		$this->start_controls_tabs( 'acc_header_tabs' );

		// IDLE TAB
		$this->start_controls_tab(
			'acc_header_normal',
			[ 'label' => esc_html__( 'Idle', 'littledino-core' ) ]
		);

		$this->add_control(
			'acc_title_color',
			[
				'label' => esc_html__( 'Title Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $header_font_color,
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'acc_title_bg_color',
			[
				'label' => esc_html__( 'Title Background Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'acc_title_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'acc_title_border',
				'selector' => '{{WRAPPER}} .wgl-accordion_header',
			]
		);

		$this->end_controls_tab();


		// HOVER TAB
		$this->start_controls_tab(
			'acc_header_hover',
			[ 'label' => esc_html__( 'Hover', 'littledino-core' )]
		);

		$this->add_control(
			'acc_title_color_hover',
			[
				'label' => esc_html__( 'Title Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $theme_color,
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'acc_title_bg_color_hover',
			[
				'label' => esc_html__( 'Title Background Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'acc_title_border_radius_hover',
			[
				'label' => esc_html__( 'Border Radius', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'acc_title_border_hover',
				'selector' => '{{WRAPPER}} .wgl-accordion_header:hover',
			]
		);

		$this->end_controls_tab();


		// ACTIVE TAB
		$this->start_controls_tab(
			'acc_header_active',
			[ 'label' => esc_html__( 'Active', 'littledino-core') ]
		);

		$this->add_control(
			'acc_title_color_active',
			[
				'label' => esc_html__( 'Title Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $theme_color,
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header.active' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'acc_title_bg_color_active',
			[
				'label' => esc_html__( 'Title Background Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header.active' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'acc_title_border_radius_active',
			[
				'label' => esc_html__( 'Border Radius', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header.active' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'acc_title_border_active',
				'selector' => '{{WRAPPER}} .wgl-accordion_header.active',
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section(); 


		/*-----------------------------------------------------------------------------------*/
		/*  STYLE -> ICON
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_style_icon',
			[
				'label' => esc_html__( 'Icon', 'littledino-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'acc_icon_size',
			[
				'label' => esc_html__( 'Icon Size', 'littledino-core'),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 22,
					'unit' => 'px',
				],
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_icon' => 'font-size: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'enable_acc_icon' => 'custom',
				],
			]
		);

		$this->add_responsive_control(
			'acc_icon_padding',
			[
				'label' => esc_html__( 'Padding', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'default' => [
					'top' => 24,
					'right' => 24,
					'bottom' => 24,
					'left' => 24,
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'acc_icon_margin',
			[
				'label' => esc_html__( 'Margin', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'acc_icon_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'default' => [
					'top' => 24,
					'right' => 24,
					'bottom' => 24,
					'left' => 24,
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		// TABS
		$this->start_controls_tabs( 'acc_icon_tabs' );

		// IDLE TAB
		$this->start_controls_tab(
			'acc_icon_normal',
			[ 'label' => esc_html__( 'Idle', 'littledino-core' )]
		);

		$this->add_control(
			'acc_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $theme_color,
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_icon' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'acc_icon_bg_color',
			[
				'label' => esc_html__( 'Icon Background Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_icon' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();


		// HOVER TAB
		$this->start_controls_tab(
			'acc_icon_hover',
			[ 'label' => esc_html__( 'Hover', 'littledino-core' )]
		);

		$this->add_control(
			'acc_icon_color_hover',
			[
				'label' => esc_html__( 'Icon Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header:hover .wgl-accordion_icon' => 'color: {{VALUE}};',
				],
			]
		);    

		$this->add_control(
			'acc_icon_bg_color_hover',
			[
				'label' => esc_html__( 'Icon Background Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $theme_color,
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header:hover .wgl-accordion_icon' => 'background-color: {{VALUE}};',
				],
			]
		);    

		$this->end_controls_tab();


		// ACTIVE TAB
		$this->start_controls_tab('acc_icon_active', ['label' => esc_html__( 'Active', 'littledino-core' )]);

		$this->add_control(
			'acc_icon_color_active',
			[
				'label' => esc_html__( 'Icon Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header.active .wgl-accordion_icon' => 'color: {{VALUE}};',
				],
			]
		);    

		$this->add_control(
			'acc_icon_bg_color_active',
			[
				'label' => esc_html__( 'Icon Background Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $theme_color,
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_header.active .wgl-accordion_icon' => 'background-color: {{VALUE}};',
				],
			]
		);    

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section(); 


		/*-----------------------------------------------------------------------------------*/
		/*  STYLE -> CONTENT
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_style_content',
			[
				'label' => esc_html__( 'Content', 'littledino-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'acc_content_typo',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .wgl-accordion_content',
			]
		);

		$this->add_responsive_control(
			'acc_content_padding',
			[
				'label' => esc_html__( 'Padding', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'default' => [
					'top' => 0,
					'right' => 5,
					'bottom' => 5,
					'left' => 75,
					'unit' => 'px',
					'isLinked' => false
				],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'acc_content_margin',
			[
				'label' => esc_html__( 'Margin', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'acc_content_color',
			[
				'label' => esc_html__( 'Content Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $main_font_color,
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_content' => 'color: {{VALUE}};',
				],
			]
		);    

		$this->add_control(
			'acc_content_bg_color',
			[
				'label' => esc_html__( 'Content Background Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_content' => 'background-color: {{VALUE}};',
				],
			]
		);    

		$this->add_control(
			'acc_content_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .wgl-accordion_content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'acc_content_border',
				'selector' => '{{WRAPPER}} .wgl-accordion_content',
			]
		);

		$this->end_controls_section();   

	}

	protected function render() {
		
		$settings = $this->get_settings_for_display();
		$id_int = substr($this->get_id_int(), 0, 3);

		$this->add_render_attribute(
			'accordion',
			[
				'class' => [
					'wgl-accordion', 
					'icon-'.$settings['enable_acc_icon'],
				],
				'id' => 'wgl-accordion-'.esc_attr( $this->get_id() ),
				'data-type' => $settings['acc_type'],
			]
		);

		?>
		<div <?php echo $this->get_render_attribute_string( 'accordion' ); ?>>

			<?php
			foreach ( $settings['acc_tab'] as $tab_count => $item ) :

				$tab_title_key = $this->get_repeater_setting_key( 'acc_tab_title', 'acc_tab', $tab_count );

				$this->add_render_attribute( $tab_title_key, [
					'id' => 'wgl-accordion_header-' . $id_int . ++$tab_count,
					'class' => [ 'wgl-accordion_header' ],
					'data-default' => $item['acc_tab_def_active'],
				] );
				
				?>
				<div class="wgl-accordion_panel">
					<<?php echo $settings['acc_title_tag']; ?> <?php echo $this->get_render_attribute_string( $tab_title_key ); ?>>
						<span class="wgl-accordion_title"><?php echo $item['acc_tab_title'] ?></span>
						<?php if ($settings['enable_acc_icon'] != 'none'): ?><i class="wgl-accordion_icon <?php echo $settings['acc_icon'] ?>"></i><?php endif;?>
					</<?php echo $settings['acc_title_tag']; ?>>
					<div class="wgl-accordion_content">
						<?php 
						if ( $item['acc_content_type'] == 'content' ) {
							echo do_shortcode($item['acc_content']);
						} else if( $item['acc_content_type'] == 'template' ) {
							$id = $item['acc_content_templates'];
							$wgl_frontend = new Frontend;
							echo $wgl_frontend->get_builder_content_for_display( $id, true );
						}
						?>
					</div>
				</div>
			<?php endforeach; ?>

		</div>
		<?php
	}
}