<?php

namespace WglAddons\Widgets;

if ( ! defined( 'ABSPATH' ) ) exit; // Abort, if accessed directly.

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Control_Media;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Utils;
use Elementor\Group_Control_Css_Filter;


class Wgl_Video_Popup extends Widget_Base {

	public function get_name() {
		return 'wgl-video-popup';
	}

	public function get_title() {
		return esc_html__( 'WGL Video Popup', 'littledino-core' );
	}

	public function get_icon() {
		return 'wgl-video-popup';
	}
 
	public function get_categories() {
		return [ 'wgl-extensions' ];
	}

	public function get_script_depends() {
		return [ 'swipebox' ];
	}

	protected function _register_controls() {
		$theme_color = esc_attr(\LittleDino_Theme_Helper::get_option('theme-custom-color'));
		$main_font_color = esc_attr(\LittleDino_Theme_Helper::get_option('main-font')['color']);
		$header_font_color = esc_attr(\LittleDino_Theme_Helper::get_option('header-font')['color']);
		

		/*-----------------------------------------------------------------------------------*/
		/*  CONTENT -> GENERAL
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_content_general',
			[ 'label' => esc_html__( 'General', 'littledino-core' ) ]
		);

		$this->add_control(
			'vp_title',
			[
				'label' => esc_html__( 'Title', 'littledino-core' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [ 'active' => true ],
				'placeholder' => esc_html__( 'Type your title', 'littledino-core' ),
			]
		);

		$this->add_control(
			'link',
			[
				'label' => esc_html__( 'Video Link', 'littledino-core' ),
				'type' => Controls_Manager::URL,
				'dynamic' => [ 'active' => true ],
				'separator' => 'after',
				'label_block' => true,
				'placeholder' => esc_html__( 'https://your-link.com', 'littledino-core' ),
				'description' => esc_html__( 'Enter video link from youtube or vimeo.', 'littledino-core' ),
				'default' => [  'url' => 'https://www.youtube.com/watch?v=TKnufs85hXk' ],
			]
		);

		$this->add_responsive_control(
			'button_pos',
			[
				'label' => esc_html__( 'Alignment', 'littledino-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'littledino-core' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'littledino-core' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'littledino-core' ),
						'icon' => 'fa fa-align-right',
					],
					'inline' => [
						'title' => esc_html__( 'Inline', 'littledino-core' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],
				'default' => 'center',
			]
		);

		$this->add_control(
			'title_pos',
			[
				'label' => esc_html__( 'Title Position', 'littledino-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'top' => [
						'title' => esc_html__( 'Top', 'littledino-core' ), 
						'icon' => 'eicon-v-align-bottom',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'littledino-core' ),
						'icon' => 'eicon-h-align-left',
					],
					'bot' => [
						'title' => esc_html__( 'Bottom', 'littledino-core' ),
						'icon' => 'eicon-v-align-top',
					],
					'left' => [
						'title' => esc_html__( 'Left', 'littledino-core' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'label_block' => false,
				'default' => 'bot',
				'toggle' => true,
			]
		);
		
		$this->add_control(
			'bg_image',
			[
				'label' => esc_html__( 'Background Image', 'littledino-core' ),
				'type' => Controls_Manager::MEDIA,
				'label_block' => true,
				'description' => esc_html__( 'Select video background image.', 'littledino-core' ),
				'separator' => 'after',
			]
		);

		$this->end_controls_section(); 


		/*-----------------------------------------------------------------------------------*/
		/*  STYLE -> TITLE STYLES
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_style_title',
			[
				'label' => esc_html__( 'Title', 'littledino-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);            

		$this->add_responsive_control(
			'title_margin',
			[
				'label' => esc_html__( 'Margin', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typo',
				'selector' => '{{WRAPPER}} .title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => $header_font_color,
				'selectors' => [
					'{{WRAPPER}} .title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label' => esc_html__( 'HTML Tag', 'littledino-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
					'div' => 'div',
				],
				'default' => 'h3',
			]
		);

		$this->end_controls_section(); 

		$this->start_controls_section(
			'section_style_button',
			[
				'label' => esc_html__( 'Button', 'littledino-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);  

		$this->add_responsive_control(
			'button_margin',
			[
				'label' => esc_html__( 'Margin', 'littledino-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'default'   => [
                    'top' => 15,
                    'right' => 15,
                    'bottom' => 15,
                    'left' => 15,
                    'unit'  => 'px',
                ],
				'selectors' => [
					'{{WRAPPER}} .videobox_link' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'button_size',
			[
				'label' => esc_html__( 'Button Size', 'littledino-core' ),
				'type' => Controls_Manager::SLIDER,
				'description' => esc_html__( 'Enter button diameter in pixels.', 'littledino-core' ),
				'range' => [
					'px' => [ 'max' => 200 ],
				],
				'size_units' => [ 'px' ],
				'default' => [
					'size' => 80,
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .videobox_link' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'bg_color',
				'label' => esc_html__( 'Button Background', 'littledino-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .videobox_link',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'button_border',
				'label' => esc_html__( 'Border Type', 'littledino-core' ),
				'selector' => '{{WRAPPER}} .videobox_link',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'button_shadow',
				'selector' => '{{WRAPPER}} .videobox_link',
			]
		);

		$this->add_control(
			'heading_triangle',
			[
				'label' => esc_html__( 'Triangle Settings', 'littledino-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'triangle_size',
			[
				'label' => esc_html__( 'Size', 'littledino-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [ 'max' => 100 ],
				],
				'size_units' => [ 'px', '%'],
				'default' => [
					'size' => 25,
					'unit' => '%',
				],
				'selectors' => [
					'{{WRAPPER}} .videobox_icon' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'triangle_color',
			[
				'label' => esc_html__( 'Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .videobox_icon' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'triangle_corners',
			[
				'label' => esc_html__( 'Rounded Corners?','littledino-core' ),
				'type' => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		/*-----------------------------------------------------------------------------------*/
		/*  STYLE -> ANIMATION
		/*-----------------------------------------------------------------------------------*/

		$this->start_controls_section(
			'section_style_animation',
			[
				'label' => esc_html__( 'Animation', 'littledino-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);            

		$this->add_control(
			'animation_style',
			[
				'label' => esc_html__( 'Select Animation Style', 'littledino-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'circles' => esc_html__( 'Pulsing Circles', 'littledino-core' ), 
					'ring_pulse' => esc_html__( 'Pulsing Ring', 'littledino-core' ),
					'ring_rotate' => esc_html__( 'Rotating Ring', 'littledino-core' ),
					'dash_rotate' => esc_html__( 'Rotating Dashes', 'littledino-core' ),
				],
				'default' => 'dash_rotate',
			]
		);

		$this->add_control(
			'circles_color',
			[
				'label' => esc_html__( 'Circles Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [ 'animation_style' => 'circles' ],
				'default' => $theme_color,
				'selectors' => [
					'{{WRAPPER}} .videobox_animation' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'ring_pusle_color',
			[
				'label' => esc_html__( 'Ring Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [ 'animation_style' => 'ring_pulse' ],
				'selectors' => [
					'{{WRAPPER}} .videobox_animation' => 'background-color: {{VALUE}}; opacity: 1',
				],
			]
		);

		$this->add_control(
			'ring_rotate_color',
			[
				'label' => esc_html__( 'Ring Elements Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [ 'animation_style' => 'ring_rotate' ],
				'selectors' => [
					'{{WRAPPER}} .videobox_animation svg g path' => 'stroke: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'dashes_color',
			[
				'label' => esc_html__( 'Dashes Color', 'littledino-core' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [ 'animation_style' => 'dash_rotate' ],
				'selectors' => [
					'{{WRAPPER}} .videobox_link' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'dashes_offset',
			[
				'label' => esc_html__( 'Dashes Offset', 'littledino-core' ),
				'type' => Controls_Manager::SLIDER,
				'condition' => [ 'animation_style' => 'dash_rotate' ],
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [ 'min' => 2, 'max' => 25 ],
				],
				'default' => [ 'size' => 12, 'unit' => 'px' ],
			]
		);

		$this->add_control(
			'always_run_animation',
			[
				'label' => esc_html__( 'Always Run Animation','littledino-core' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'On', 'littledino-core' ),
				'label_off' => esc_html__( 'Off', 'littledino-core' ),
				'description' => esc_html__( 'Run until hover state.', 'littledino-core' ),
				'return_value' => 'yes',
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		
		// Enqueue swipebox style
		wp_enqueue_style( 'swipebox', get_template_directory_uri() . '/js/swipebox/css/swipebox.min.css');

		$_s = $this->get_settings_for_display();

		$this->add_render_attribute(
			[
				'video-wrap' => [
					'class' => [
						'wgl-video-popup',
						'button_align-'.$_s['button_pos'],
						'animation_'.$_s['animation_style'],
						'title_pos-'.$_s['title_pos'],
						$_s['bg_image']['url'] ? 'with_image' : '',
						$_s['always_run_animation'] ? 'always-run-animation' : '',
					],
				],
				'video-link' => [
					'class' => 'videobox videobox_link',
					'href' => $_s['link'] ? esc_url($_s['link']['url']) : '#',
					'data-rel' => 'youtube-'.uniqid(),
					'target' => $_s['link']['is_external'] ? '_blank' : '_self',
					'rel' => $_s['link']['nofollow'] ? 'nofollow' : 'external',
				],
			]
		);

		// Animation element
		switch ($_s['animation_style']) {
			case 'circles':
				$animated_element = '<div class="videobox_animation circle_1"></div>';
				$animated_element .= '<div class="videobox_animation circle_2"></div>';
				$animated_element .= '<div class="videobox_animation circle_3"></div>';	
				break;
			case 'ring_pulse':
				$animated_element = '<div class="videobox_animation ring_1"></div>';
				break;
			case 'ring_rotate':
				$svg_ring_circle_color = !empty($_s['anim_color']) ? 'rgba('.\LittleDino_Theme_Helper::HexToRGB($_s['anim_color']).', 0.1)' : 'rgba(0,0,0,0.1)';
				$svg_ring = '<svg class="ring_1" viewBox="0 0 202 202">';
					$svg_ring .= '<g fill="none" stroke-width="1">';
						$svg_ring .= '<circle stroke="'.$svg_ring_circle_color.'" cx="101" cy="101" r="100"/>';
						$svg_ring .= '<path stroke="'.esc_attr($_s['anim_color']).'" d="M74,197.3c-33.5-9.4-59.9-35.8-69.3-69.2"/>';
						$svg_ring .= '<path stroke="'.esc_attr($_s['anim_color']).'" d="M128,4.7c33.5,9.4,59.9,35.8,69.3,69.3"/>';
					$svg_ring .= '</g>';
				$svg_ring .= '</svg>';
				$animated_element = '<div class="videobox_animation">';
				$animated_element .= $svg_ring;
				$animated_element .= '</div>';
				break;
			case 'dash_rotate':
		
				$rect = []; $svg_style = '';
				if ( $_s['dashes_offset']['size'] ) {
					$svg_style = 'top: -'. $_s['dashes_offset']['size'] * 2 . 'px;';
					$svg_style .= ' left: -'. $_s['dashes_offset']['size'] * 2 . 'px;';
					$svg_style .= ' width: calc(100% + ' . $_s['dashes_offset']['size'] * 4 . 'px);';
					$svg_style .= ' height: calc(100% + ' . $_s['dashes_offset']['size'] * 4 . 'px);';

					$rect['x/y'] = $_s['dashes_offset']['size'] . $_s['dashes_offset']['unit'];
				}

				$this->add_render_attribute(
					[
						'svg' => [
							'class' => 'wgl-dashes',
							'style' => $svg_style ? $svg_style : '',
						],
						'rect' => [
							'x' => !empty($rect['x/y']) ? $rect['x/y'] : '12',
							'y' => !empty($rect['x/y']) ? $rect['x/y'] : '12',
							'rx' => '50%',
							'ry' => '50%',
							'width' => '0',
							'height' => '0',
						],
					]
				);
				$animated_element = sprintf( '<svg %s><rect %s></rect></svg>',
					$this->get_render_attribute_string('svg'),
					$this->get_render_attribute_string('rect')
				);
				break;
			default: $animated_element = '';
		}

		// Triangle svg
		switch ($_s['triangle_corners']) {
			case false:
				$triangle_svg = '<svg class="videobox_icon" viewBox="0 0 10 10"><polygon points="1,0 1,10 8.5,5"/></svg>';
				break;
			case true:
				$triangle_svg = '<svg class="videobox_icon" viewBox="0 0 232 232"><path d="M203,99L49,2.3c-4.5-2.7-10.2-2.2-14.5-2.2 c-17.1,0-17,13-17,16.6v199c0,2.8-0.07,16.6,17,16.6c4.3,0,10,0.4,14.5-2.2 l154-97c12.7-7.5,10.5-16.5,10.5-16.5S216,107,204,100z"/></svg>';
				break;
		}

		// Render
		printf( '<div %s>', $this->get_render_attribute_string('video-wrap') );
			?>
			<div class="videobox_content">
				<?php
				if ( $_s['bg_image']['url'] ) {
					echo '<div class="videobox_background">', wp_get_attachment_image( $_s['bg_image']['id'] , 'full' ), '</div>';
					echo '<div class="videobox_link_wrapper">';
				}
				if ( $_s['vp_title'] )
					printf( '<%1$s class="title">%2$s</%1$s>',
						$_s['title_tag'],
						esc_html__($_s['vp_title'])
					);
				printf( '<a %s>%s%s</a>',
					$this->get_render_attribute_string('video-link'),
					$triangle_svg,
					$animated_element
				);
				if ( $_s['bg_image']['url'] ) echo '</div>';
				?>
			</div>
		</div>
		<?php
	}
}